# frozen_string_literal: true

source "https://rubygems.org"

gem "fileutils", "1.7.3"
gem "molinillo", github: "cocoapods/molinillo"
gem "net-http", github: "ruby/net-http", ref: "d8fd39c589279b1aaec85a7c8de9b3e199c72efe"
gem "net-http-persistent", github: "hsbt/net-http-persistent", ref: "9b6fbd733cf35596dfe7f80c0c154f9f3d17dbdb"
gem "net-protocol", "0.2.2"
gem "optparse", "0.6.0"
gem "pub_grub", github: "jhawthorn/pub_grub", ref: "df6add45d1b4d122daff2f959c9bd1ca93d14261"
gem "resolv", "0.6.2"
gem "securerandom", "0.4.1"
gem "timeout", "0.4.3"
gem "thor", "1.3.2"
gem "tsort", "0.2.0"
gem "uri", "1.0.3"
